# signadot-sdk
API for Signadot Workspaces

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0
- Package version: 0.0.1
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import signadot_sdk 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import signadot_sdk
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import signadot_sdk
from signadot_sdk.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = signadot_sdk.Configuration()
configuration.api_key['signadot-api-key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['signadot-api-key'] = 'Bearer'

# create an instance of the API class
api_instance = signadot_sdk.ClusterApi(signadot_sdk.ApiClient(configuration))
org_name = 'my-company' # str | Signadot Org Name
data = signadot_sdk.ConnectClusterRequest() # ConnectClusterRequest | Request to create cluster

try:
    # Connect Cluster
    api_response = api_instance.connect_cluster(org_name, data)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ClusterApi->connect_cluster: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.signadot.com/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ClusterApi* | [**connect_cluster**](docs/ClusterApi.md#connect_cluster) | **POST** /orgs/{orgName}/clusters | Connect Cluster
*ClusterApi* | [**create_cluster_token**](docs/ClusterApi.md#create_cluster_token) | **POST** /orgs/{orgName}/clusters/{clusterName}/tokens | Create Cluster Token
*ClusterApi* | [**delete_cluster_token**](docs/ClusterApi.md#delete_cluster_token) | **DELETE** /orgs/{orgName}/clusters/{clusterName}/tokens/{tokenId} | Delete Cluster Token
*WorkspacesApi* | [**create_new_workspace**](docs/WorkspacesApi.md#create_new_workspace) | **POST** /orgs/{orgName}/workspaces | Create a new workspace
*WorkspacesApi* | [**delete_workspace_by_id**](docs/WorkspacesApi.md#delete_workspace_by_id) | **DELETE** /orgs/{orgName}/workspaces/{workspaceId} | Delete a Workspace by ID
*WorkspacesApi* | [**get_workspace_by_id**](docs/WorkspacesApi.md#get_workspace_by_id) | **GET** /orgs/{orgName}/workspaces/{workspaceId} | Get a Workspace by ID
*WorkspacesApi* | [**get_workspace_ready**](docs/WorkspacesApi.md#get_workspace_ready) | **GET** /orgs/{orgName}/workspaces/{workspaceID}/ready | Check workspace readiness
*WorkspacesApi* | [**get_workspaces**](docs/WorkspacesApi.md#get_workspaces) | **GET** /orgs/{orgName}/workspaces | List Workspaces
*WorkspacesApi* | [**upsert_pr_workspace**](docs/WorkspacesApi.md#upsert_pr_workspace) | **POST** /repos/{githubOrg}/{githubRepo}/pulls/{prNumber}/workspaces | Create or Update workspace from Pull Request


## Documentation For Models

 - [Branch](docs/Branch.md)
 - [ConnectClusterRequest](docs/ConnectClusterRequest.md)
 - [ConnectClusterResponse](docs/ConnectClusterResponse.md)
 - [CreateClusterTokenResponse](docs/CreateClusterTokenResponse.md)
 - [CreatePreviewEndpointRequest](docs/CreatePreviewEndpointRequest.md)
 - [CreateWorkspaceRequest](docs/CreateWorkspaceRequest.md)
 - [CreateWorkspaceResponse](docs/CreateWorkspaceResponse.md)
 - [EnvOp](docs/EnvOp.md)
 - [ForkEndpoint](docs/ForkEndpoint.md)
 - [ForkOf](docs/ForkOf.md)
 - [GetWorkspaceByIdResponse](docs/GetWorkspaceByIdResponse.md)
 - [GetWorkspacesResponse](docs/GetWorkspacesResponse.md)
 - [HandlerEmptyResponse](docs/HandlerEmptyResponse.md)
 - [Image](docs/Image.md)
 - [PreviewEndpoint](docs/PreviewEndpoint.md)
 - [UpsertPRWorkspacesRequest](docs/UpsertPRWorkspacesRequest.md)
 - [UpsertWorkspaceResponse](docs/UpsertWorkspaceResponse.md)
 - [V1ImageReplacement](docs/V1ImageReplacement.md)
 - [WorkspaceCustomizations](docs/WorkspaceCustomizations.md)
 - [WorkspaceDetails](docs/WorkspaceDetails.md)
 - [WorkspaceEndpoint](docs/WorkspaceEndpoint.md)
 - [WorkspaceFork](docs/WorkspaceFork.md)
 - [WorkspaceInfo](docs/WorkspaceInfo.md)
 - [WorkspaceReadyResponse](docs/WorkspaceReadyResponse.md)


## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: signadot-api-key
- **Location**: HTTP header


## Author



